app

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsUsage

func IsUsage(err error) bool

func Run

func Run(stdout, stderr io.Writer, args []string) error

Run executes the facts command with the provided arguments.

Types

type ExitStatus

type ExitStatus int

ExitStatus reports a command status that should not be printed as an error.

func (ExitStatus) Code

func (s ExitStatus) Code() int

func (ExitStatus) Error

func (s ExitStatus) Error() string

Jump to